@@ -154,14 +154,14 @@ pub trait DocumentOps {
     /// # use ironoxide::prelude::*;
     /// # let sdk: IronOxide = unimplemented!();
     /// # use ironoxide::document::DocumentEncryptOpts;
-    /// let data = "secret data".as_bytes();
+    /// let data = "secret data".to_string().into_bytes();
     /// let encrypted = sdk.document_encrypt(data, &DocumentEncryptOpts::default()).await?;
     /// # Ok(())
     /// # }
     /// ```
     async fn document_encrypt(
         &self,
-        document_data: &[u8],
+        document_data: Vec<u8>,
         encrypt_opts: &DocumentEncryptOpts,
     ) -> Result<DocumentEncryptResult>;
 
@@ -262,7 +262,7 @@ pub trait DocumentOps {
     /// # use ironoxide::prelude::*;
     /// # let sdk: IronOxide = unimplemented!();
     /// # let document_id: DocumentId = unimplemented!();
-    /// let new_data = "more secret data".as_bytes();
+    /// let new_data = "more secret data".to_string().into_bytes();
     /// let encrypted = sdk.document_update_bytes(&document_id, new_data).await?;
     /// # Ok(())
     /// # }
@@ -270,7 +270,7 @@ pub trait DocumentOps {
     async fn document_update_bytes(
         &self,
         id: &DocumentId,
-        new_document_data: &[u8],
+        new_document_data: Vec<u8>,
     ) -> Result<DocumentEncryptResult>;
 
     /// Modifies or removes a document's name.
@@ -329,7 +329,7 @@ pub trait DocumentOps {
     async fn document_grant_access(
         &self,
         document_id: &DocumentId,
-        grant_list: &Vec<UserOrGroup>,
+        grant_list: &[UserOrGroup],
     ) -> Result<DocumentAccessResult>;
 
     /// Revokes decryption access to a document for the provided users and/or groups.
@@ -362,7 +362,7 @@ pub trait DocumentOps {
     async fn document_revoke_access(
         &self,
         document_id: &DocumentId,
-        revoke_list: &Vec<UserOrGroup>,
+        revoke_list: &[UserOrGroup],
     ) -> Result<DocumentAccessResult>;
 }
 
@@ -370,7 +370,7 @@ pub trait DocumentOps {
 impl DocumentOps for crate::IronOxide {
     async fn document_encrypt(
         &self,
-        document_data: &[u8],
+        document_data: Vec<u8>,
         encrypt_opts: &DocumentEncryptOpts,
     ) -> Result<DocumentEncryptResult> {
         let encrypt_opts = encrypt_opts.clone();
@@ -453,7 +453,7 @@ impl DocumentOps for crate::IronOxide {
     async fn document_update_bytes(
         &self,
         id: &DocumentId,
-        new_document_data: &[u8],
+        new_document_data: Vec<u8>,
     ) -> Result<DocumentEncryptResult> {
         add_optional_timeout(
             document_api::document_update_bytes(
@@ -486,7 +486,7 @@ impl DocumentOps for crate::IronOxide {
     async fn document_grant_access(
         &self,
         id: &DocumentId,
-        grant_list: &Vec<UserOrGroup>,
+        grant_list: &[UserOrGroup],
     ) -> Result<DocumentAccessResult> {
         let (users, groups) = partition_user_or_group(grant_list);
 
@@ -509,7 +509,7 @@ impl DocumentOps for crate::IronOxide {
     async fn document_revoke_access(
         &self,
         id: &DocumentId,
-        revoke_list: &Vec<UserOrGroup>,
+        revoke_list: &[UserOrGroup],
     ) -> Result<DocumentAccessResult> {
         add_optional_timeout(
             document_api::document_revoke_access(self.device.auth(), id, revoke_list),
