@@ -19,7 +19,6 @@ use crate::{
     },
     DeviceSigningKeyPair, PolicyCache,
 };
-use chrono::{DateTime, Utc};
 use futures::{try_join, Future};
 use hex::encode;
 use itertools::{Either, Itertools};
@@ -39,6 +38,7 @@ use std::{
     ops::DerefMut,
     sync::Mutex,
 };
+use time::OffsetDateTime;
 
 mod requests;
 
@@ -240,11 +240,11 @@ impl DocumentListMeta {
         &self.0.association.typ
     }
     /// Date and time when the document was created
-    pub fn created(&self) -> &DateTime<Utc> {
+    pub fn created(&self) -> &OffsetDateTime {
         &self.0.created
     }
     /// Date and time when the document was last updated
-    pub fn last_updated(&self) -> &DateTime<Utc> {
+    pub fn last_updated(&self) -> &OffsetDateTime {
         &self.0.updated
     }
 }
@@ -279,11 +279,11 @@ impl DocumentMetadataResult {
         self.0.name.as_ref()
     }
     /// Date and time when the document was created
-    pub fn created(&self) -> &DateTime<Utc> {
+    pub fn created(&self) -> &OffsetDateTime {
         &self.0.created
     }
     /// Date and time when the document was last updated
-    pub fn last_updated(&self) -> &DateTime<Utc> {
+    pub fn last_updated(&self) -> &OffsetDateTime {
         &self.0.updated
     }
     /// How the requesting user has access to the document
@@ -370,8 +370,8 @@ impl DocumentEncryptUnmanagedResult {
 pub struct DocumentEncryptResult {
     id: DocumentId,
     name: Option<DocumentName>,
-    updated: DateTime<Utc>,
-    created: DateTime<Utc>,
+    updated: OffsetDateTime,
+    created: OffsetDateTime,
     encrypted_data: Vec<u8>,
     grants: Vec<UserOrGroup>,
     access_errs: Vec<DocAccessEditErr>,
@@ -390,11 +390,11 @@ impl DocumentEncryptResult {
         self.name.as_ref()
     }
     /// Date and time when the document was created
-    pub fn created(&self) -> &DateTime<Utc> {
+    pub fn created(&self) -> &OffsetDateTime {
         &self.created
     }
     /// Date and time when the document was last updated
-    pub fn last_updated(&self) -> &DateTime<Utc> {
+    pub fn last_updated(&self) -> &OffsetDateTime {
         &self.updated
     }
     /// Users and groups the document was successfully encrypted to
@@ -413,8 +413,8 @@ impl DocumentEncryptResult {
 pub struct DocumentDecryptResult {
     id: DocumentId,
     name: Option<DocumentName>,
-    updated: DateTime<Utc>,
-    created: DateTime<Utc>,
+    updated: OffsetDateTime,
+    created: OffsetDateTime,
     decrypted_data: Vec<u8>,
 }
 impl DocumentDecryptResult {
@@ -431,11 +431,11 @@ impl DocumentDecryptResult {
         self.name.as_ref()
     }
     /// Date and time when the document was created
-    pub fn created(&self) -> &DateTime<Utc> {
+    pub fn created(&self) -> &OffsetDateTime {
         &self.created
     }
     /// Date and time when the document was last updated
-    pub fn last_updated(&self) -> &DateTime<Utc> {
+    pub fn last_updated(&self) -> &OffsetDateTime {
         &self.updated
     }
 }
@@ -588,21 +588,20 @@ pub async fn encrypt_document<
     recrypt: &Recrypt<Sha256, Ed25519, RandomBytes<R1>>,
     user_master_pub_key: &PublicKey,
     rng: &Mutex<R2>,
-    plaintext: &[u8],
+    plaintext: Vec<u8>,
     document_id: Option<DocumentId>,
     document_name: Option<DocumentName>,
     grant_to_author: bool,
-    user_grants: &Vec<UserId>,
-    group_grants: &Vec<GroupId>,
+    user_grants: &[UserId],
+    group_grants: &[GroupId],
     policy_grant: Option<&PolicyGrant>,
     policy_cache: &PolicyCache,
 ) -> Result<DocumentEncryptResult, IronOxideErr> {
     let (dek, doc_sym_key) = transform::generate_new_doc_key(recrypt);
     let doc_id = document_id.unwrap_or_else(|| DocumentId::goo_id(rng));
-    let pt_bytes = plaintext.to_vec();
 
     let (encrypted_doc, (grants, key_errs)) = try_join!(
-        aes::encrypt_async(rng, &pt_bytes, *doc_sym_key.bytes()),
+        aes::encrypt_async(rng, plaintext, *doc_sym_key.bytes()),
         resolve_keys_for_grants(
             auth,
             config,
@@ -610,7 +609,7 @@ pub async fn encrypt_document<
             group_grants,
             policy_grant,
             if grant_to_author {
-                Some(&user_master_pub_key)
+                Some(user_master_pub_key)
             } else {
                 None
             },
@@ -654,8 +653,8 @@ type UserMasterPublicKey = PublicKey;
 async fn resolve_keys_for_grants(
     auth: &RequestAuth,
     config: &IronOxideConfig,
-    user_grants: &Vec<UserId>,
-    group_grants: &Vec<GroupId>,
+    user_grants: &[UserId],
+    group_grants: &[GroupId],
     policy_grant: Option<&PolicyGrant>,
     maybe_user_master_pub_key: Option<&UserMasterPublicKey>,
     policy_cache: &PolicyCache,
@@ -747,11 +746,11 @@ pub async fn encrypt_document_unmanaged<R1, R2>(
     recrypt: &Recrypt<Sha256, Ed25519, RandomBytes<R1>>,
     user_master_pub_key: &PublicKey,
     rng: &Mutex<R2>,
-    plaintext: &[u8],
+    plaintext: Vec<u8>,
     document_id: Option<DocumentId>,
     grant_to_author: bool,
-    user_grants: &Vec<UserId>,
-    group_grants: &Vec<GroupId>,
+    user_grants: &[UserId],
+    group_grants: &[GroupId],
     policy_grant: Option<&PolicyGrant>,
 ) -> Result<DocumentEncryptUnmanagedResult, IronOxideErr>
 where
@@ -763,10 +762,9 @@ where
 
     let (dek, doc_sym_key) = transform::generate_new_doc_key(recrypt);
     let doc_id = document_id.unwrap_or_else(|| DocumentId::goo_id(rng));
-    let pt_bytes = plaintext.to_vec();
 
     let (encryption_result, (grants, key_errs)) = try_join!(
-        aes::encrypt_async(rng, &pt_bytes, *doc_sym_key.bytes()),
+        aes::encrypt_async(rng, plaintext, *doc_sym_key.bytes()),
         resolve_keys_for_grants(
             auth,
             &config,
@@ -774,7 +772,7 @@ where
             group_grants,
             policy_grant,
             if grant_to_author {
-                Some(&user_master_pub_key)
+                Some(user_master_pub_key)
             } else {
                 None
             },
@@ -979,10 +977,12 @@ impl EncryptedDoc {
             .collect();
         let proto_edek_vec = proto_edek_vec_results?;
 
-        let mut proto_edeks = EncryptedDeksP::default();
-        proto_edeks.edeks = RepeatedField::from_vec(proto_edek_vec);
-        proto_edeks.documentId = self.header.document_id.id().into();
-        proto_edeks.segmentId = self.header.segment_id as i32; // okay since the ironcore-ws defines this to be an i32
+        let proto_edeks = EncryptedDeksP {
+            edeks: RepeatedField::from_vec(proto_edek_vec),
+            documentId: self.header.document_id.id().into(),
+            segmentId: self.header.segment_id as i32, // okay since the ironcore-ws defines this to be an i32
+            ..Default::default()
+        };
 
         let edek_bytes = proto_edeks.write_to_bytes()?;
         Ok(edek_bytes)
@@ -1027,7 +1027,7 @@ pub async fn document_update_bytes<
     device_private_key: &PrivateKey,
     rng: &Mutex<R2>,
     document_id: &DocumentId,
-    plaintext: &[u8],
+    plaintext: Vec<u8>,
 ) -> Result<DocumentEncryptResult, IronOxideErr> {
     let doc_meta = document_get_metadata(auth, document_id).await?;
     let sym_key = transform::decrypt_as_symmetric_key(
@@ -1036,7 +1036,7 @@ pub async fn document_update_bytes<
         device_private_key.recrypt_key(),
     )?;
     Ok(
-        aes::encrypt(rng, &plaintext.to_vec(), *sym_key.bytes()).map(move |encrypted_doc| {
+        aes::encrypt(rng, plaintext, *sym_key.bytes()).map(move |encrypted_doc| {
             let mut encrypted_payload =
                 DocumentHeader::new(document_id.clone(), auth.segment_id()).pack();
             encrypted_payload.0.append(&mut encrypted_doc.bytes());
@@ -1104,7 +1104,7 @@ pub async fn decrypt_document_unmanaged<CR: rand::CryptoRng + rand::RngCore>(
                 parse_document_parts(encrypted_doc)?,
             ))
         },
-        requests::edek_transform::edek_transform(&auth, encrypted_deks,)
+        requests::edek_transform::edek_transform(auth, encrypted_deks,)
     )?;
 
     edeks_and_header_match_or_err(&proto_edeks, &doc_meta)?;
@@ -1164,8 +1164,8 @@ pub async fn document_grant_access<CR: rand::CryptoRng + rand::RngCore>(
     id: &DocumentId,
     user_master_pub_key: &PublicKey,
     priv_device_key: &PrivateKey,
-    user_grants: &Vec<UserId>,
-    group_grants: &Vec<GroupId>,
+    user_grants: &[UserId],
+    group_grants: &[GroupId],
 ) -> Result<DocumentAccessResult, IronOxideErr> {
     let (doc_meta, users, groups) = try_join!(
         document_get_metadata(auth, id),
@@ -1211,7 +1211,7 @@ pub async fn document_grant_access<CR: rand::CryptoRng + rand::RngCore>(
 pub async fn document_revoke_access(
     auth: &RequestAuth,
     id: &DocumentId,
-    revoke_list: &Vec<UserOrGroup>,
+    revoke_list: &[UserOrGroup],
 ) -> Result<DocumentAccessResult, IronOxideErr> {
     use requests::document_access::{self, resp};
 
