@@ -124,7 +124,7 @@
 //! # use ironoxide::prelude::*;
 //! # let sdk: IronOxide = unimplemented!();
 //! use ironoxide::document::DocumentEncryptOpts;
-//! let data = "secret data".as_bytes();
+//! let data = "secret data".to_string().into_bytes();
 //! let encrypted = sdk.document_encrypt(data, &DocumentEncryptOpts::default()).await?;
 //! let encrypted_bytes = encrypted.encrypted_data();
 //! # Ok(())
@@ -147,6 +147,8 @@
 //! # }
 //! ```
 
+#![allow(clippy::too_many_arguments)]
+#![allow(clippy::type_complexity)]
 // required by quick_error or IronOxideErr
 #![recursion_limit = "128"]
 // required as of rust 1.46.0
@@ -358,7 +360,7 @@ pub async fn initialize(
 /// Finds the groups that the caller is an admin of that need rotation and
 /// forms an InitAndRotationCheck from the user/groups needing rotation.
 fn check_groups_and_collect_rotation<T>(
-    groups: &Vec<internal::group_api::GroupMetaResult>,
+    groups: &[internal::group_api::GroupMetaResult],
     user_needs_rotation: bool,
     account_id: UserId,
     ironoxide: T,
